==> lam_6.3.2.orig.tar.gz: lam-6.3.2/share/mpi/portopen.c <==
/*
 *
 * Copyright 1998-1999, University of Notre Dame.
 * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
 *          and Andrew Lumsdaine
 *
 * This file is part of the Notre Dame LAM implementation of MPI.
 *
 * You should have received a copy of the License Agreement for the
 * Notre Dame LAM implementation of MPI along with the software; see
 * the file LICENSE.  If not, contact Office of Research, University
 * of Notre Dame, Notre Dame, IN 46556.
 *
 * Permission to modify the code and to distribute modified code is
 * granted, provided the text of this NOTICE is retained, a notice that
 * the code was modified is included with the above COPYRIGHT NOTICE and
 * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
 * file is distributed with the modified code.
 *
 * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
 * By way of example, but not limitation, Licensor MAKES NO
 * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
 * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
 * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
 * OR OTHER RIGHTS.  
 *
 * Additional copyrights may follow.
 *
 *	Ohio Trollius
 *	Copyright 1996 The Ohio State University
 *	NJN
 *
 *	$Id: portopen.c,v 6.5 1999/07/28 00:32:02 jsquyres Exp $
 *
 *	Function:	- open an MPI port
 *	Accepts:	- info
 *			- port name (out)
 *	Returns:	- MPI_SUCCESS or error code
 */

#include <sfh.h>

#include <string.h>

#include <app_mgmt.h>
#include <blktype.h>
#include <mpi.h>
#include <mpisys.h>
#include <rpisys.h>
#include <terror.h>


int
MPI_Open_port(info, port_name)

MPI_Info		info;
char			*port_name;

{
	struct _port	port;			/* new port */
	int		port_num;		/* port number */

	lam_initerr();
	lam_setfunc(BLKMPIOPENPORT);
/*
 * Open a port.
 */
	if ((port_num = lam_port_open()) < 0) {
		return(lam_errfunc(MPI_COMM_WORLD, BLKMPIOPENPORT,
				lam_mkerr(MPI_ERR_OTHER, errno)));
	}
	LAM_ZERO_ME(port);
	port.prt_num = port_num;
/*
 * Add port to list of open ports.
 */
	sprintf(port.prt_name, "n%d:i%d:%d", lam_myproc->p_gps.gps_node,
		lam_myproc->p_gps.gps_idx, port_num);
	
	if (al_find(lam_ports, &port) != 0) {
		return(lam_errfunc(MPI_COMM_WORLD, BLKMPIOPENPORT,
					lam_mkerr(MPI_ERR_INTERN, 0)));
	}
	if (al_insert(lam_ports, &port) == 0) {
		return(lam_errfunc(MPI_COMM_WORLD, BLKMPIOPENPORT,
					lam_mkerr(MPI_ERR_OTHER, errno)));
	}
/*
 * Set return value.  The MPI_MAX_PORT_NAME probably isn't necessary, but
 * hey, let's be safe.
 */
	strncpy(port_name, port.prt_name, MPI_MAX_PORT_NAME);
	
        lam_resetfunc(BLKMPIOPENPORT);
	return(MPI_SUCCESS);
}

==> lam-6.5.1.tar.gz: lam-6.5.1/share/mpi/portopen.c <==
/*
 * Copyright 1998-2001, University of Notre Dame.
 * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
 *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
 * 
 * This file is part of the Notre Dame LAM implementation of MPI.
 * 
 * You should have received a copy of the License Agreement for the Notre
 * Dame LAM implementation of MPI along with the software; see the file
 * LICENSE.  If not, contact Office of Research, University of Notre
 * Dame, Notre Dame, IN 46556.
 * 
 * Permission to modify the code and to distribute modified code is
 * granted, provided the text of this NOTICE is retained, a notice that
 * the code was modified is included with the above COPYRIGHT NOTICE and
 * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
 * file is distributed with the modified code.
 * 
 * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
 * By way of example, but not limitation, Licensor MAKES NO
 * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
 * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
 * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
 * OR OTHER RIGHTS.
 * 
 * Additional copyrights may follow.
 * 
 *	Ohio Trollius
 *	Copyright 1996 The Ohio State University
 *	NJN
 *
 *	$Id: portopen.c,v 6.7 2001/01/30 18:26:57 jsquyres Exp $
 *
 *	Function:	- open an MPI port
 *	Accepts:	- info
 *			- port name (out)
 *	Returns:	- MPI_SUCCESS or error code
 */

#include <sfh.h>

#include <string.h>

#include <app_mgmt.h>
#include <blktype.h>
#include <mpi.h>
#include <mpisys.h>
#include <rpisys.h>
#include <terror.h>

/*@
   MPI_Open_port - Establish a server port for client MPI connections

Input Parameters:
+ info - extra information handle
- port_name - newly established port

.N fortran

.N IMPI_MPI2

.N Errors
.N MPI_ERR_OTHER
.N MPI_ERR_INTERN

.seealso MPI_Close_port(3), MPI_Comm_accept(3), MPI_Comm_connect(3), MPI_Comm_disconnect(3)

.N WEB
@*/
int
MPI_Open_port(MPI_Info info, char* port_name)
{
	struct _port	port;			/* new port */
	int		port_num;		/* port number */

	lam_initerr();
	lam_setfunc(BLKMPIOPENPORT);
/*
 * Open a port.
 */
	if ((port_num = lam_port_open()) < 0) {
		return(lam_errfunc(MPI_COMM_WORLD, BLKMPIOPENPORT,
				lam_mkerr(MPI_ERR_OTHER, errno)));
	}
	LAM_ZERO_ME(port);
	port.prt_num = port_num;
/*
 * Add port to list of open ports.
 */
	sprintf(port.prt_name, "n%d:i%d:%d", lam_myproc->p_gps.gps_node,
		lam_myproc->p_gps.gps_idx, port_num);
	
	if (al_find(lam_ports, &port) != 0) {
		return(lam_errfunc(MPI_COMM_WORLD, BLKMPIOPENPORT,
					lam_mkerr(MPI_ERR_INTERN, 0)));
	}
	if (al_insert(lam_ports, &port) == 0) {
		return(lam_errfunc(MPI_COMM_WORLD, BLKMPIOPENPORT,
					lam_mkerr(MPI_ERR_OTHER, errno)));
	}
/*
 * Set return value.  The MPI_MAX_PORT_NAME probably isn't necessary, but
 * hey, let's be safe.
 */
	strncpy(port_name, port.prt_name, MPI_MAX_PORT_NAME);
	
        lam_resetfunc(BLKMPIOPENPORT);
	return(MPI_SUCCESS);
}
